# pifr

Pull docker image from remote host

```text
Usage: pifr [OPTIONS] COMMAND [ARGS]...

  Pull docker image from remote host.

Options:
  --help  Show this message and exit.

Commands:
  list  列出主机 List hosts
  pull  在主机上拉取镜像，并导入到本地 Pull image at remote host and save it to local
```
